@@ -3,7 +3,6 @@
 
 ## usethis namespace: start
 #' @importFrom rlang .data
+#' @importFrom stats setNames
 ## usethis namespace: end
 NULL
-
-globalVariables(c("af_colour_values", "af_colour_palettes"))
